@@ -1,3 +1,4 @@
+from __future__ import absolute_import, division, with_statement
 from tornado.test.httpclient_test import HTTPClientCommonTestCase
 
 try:
@@ -8,9 +9,13 @@ except ImportError:
 if pycurl is not None:
     from tornado.curl_httpclient import CurlAsyncHTTPClient
 
+
 class CurlHTTPClientCommonTestCase(HTTPClientCommonTestCase):
     def get_http_client(self):
-        return CurlAsyncHTTPClient(io_loop=self.io_loop)
+        client = CurlAsyncHTTPClient(io_loop=self.io_loop)
+        # make sure AsyncHTTPClient magic doesn't give us the wrong class
+        self.assertTrue(isinstance(client, CurlAsyncHTTPClient))
+        return client
 
 # Remove the base class from our namespace so the unittest module doesn't
 # try to run it again.
